TokenPayload class

Constructors

TokenPayload({DateTime? createdDate, required DateTime? expiredDate, Map<String, dynamic>? data})
TokenPayload.fromMap(Map<String, dynamic> payloadMap)
factory

Properties

createdDate → DateTime?
final
data → Map<String, dynamic>?
final
expiredDate → DateTime?
final
hashCode → int
The hash code for this object.
no setterinherited
isExpired → bool
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited